package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````E18``#0```"0@0````0`!30`(``)
M`"@`&P`:``$``'#@>P``X'L``.![```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``&0``
M`!D````$`````0````$```````````````````#L>P``['L```4```````$`
M`0```.Q[``#L>P$`['L!`%0$``!H%```!@```````0`"````]'L``/1[`0#T
M>P$`"`$```@!```&````!`````0```!P`0``<`$``'`!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71D['L`
M`.Q[`0#L>P$`%`0``!0$```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4`REI3%%EN6$&J'QN^1CSB4%M2<^`$
M````$`````$```!'3E4```````,````"`````````!$```!,````"`````@`
M```!D!`$)4`$@"B```6@AE"$@`$```LH!(PX@!)!B@``"$P```!-````4```
M`%0```!5````70```%X```!?`````````&$```!B````8P```&0```!E````
M:````````````````:\TZ&[%WQ_.WD<M:W^:?"[%F[;49-1\=E0\E"'_Y`[9
M<5@<XD?&`;(!BV^L2^/`0OK7A\+E/RQ8[Y=YNN.2?/NA;&!K"4/69Z_,9D)%
MU>R)!W#3,V+;[16,)<P-.I<+?ZF<F^"G`@IJ&IY0O]I7&Z/@^TD`````````
M`````````````````,P1`````````P`+````````@`$```````,`%@#G`@``
M```````````2````\P``````````````$@```'8"`````````````!(```"@
M`@`````````````2````@P``````````````$@```-$``````````````!$`
M``!L`0`````````````2````"0$`````````````$@````$`````````````
M`"````"I`0`````````````2````.@$`````````````$@```"H!````````
M`````!(````=`@`````````````2````'`$`````````````$@````@"````
M`````````!(````0```````````````@````B@$`````````````$@```"P"
M`````````````!(```#X```````````````2````I`$`````````````$@``
M`.`"`````````````!(````L```````````````@````F0(`````````````
M$@```$8``````````````!(```!<`0`````````````2````8P``````````
M````$@```,```````````````!(```!T```````````````2````5@(`````
M````````$@````$"`````````````!(```"1`@`````````````2````R0,`
M````````````$@```*0``````````````!(```#O`@`````````````1````
M^@$`````````````$@````D#`````````````!$```!#`@`````````````2
M````4`(`````````````$@```$X!`````````````!(````Z`@``````````
M```2````W```````````````$@```%T"`````````````!(```#]````````
M```````2````J`(`````````````$@```(,!`````````````!(```#/`@``
M```````````2````Y0$`````````````$@```!8"`````````````!(```!*
M`@`````````````2````F`(`````````````$@```+\!`````````````!(`
M``"W`0`````````````2````]P(`````````````$@```.X"````````````
M`"$```"/```````````````2````L`$`````````````$@```'<!````````
M`````!(```#&`@`````````````2````[0(`````````````$0```(H"````
M`````````!$```"S```````````````1````;`(`````````````$@```'P"
M`````````````!(````D`@`````````````2````0P$`````````````$@``
M`&0"`````````````!(```!4```````````````2````TP$`````````````
M$@```#,"`````````````!(```#S`0`````````````2````P0(`````````
M````$@```+`"`````````````!(```"5`0`````````````B````)`0``%20
M`0``````$``7`-(#``!]+```Z````!(`#0!)!```U20``.`%```2``T`X`$`
M`-D4``"\`0``$@`-`$D#```1'0``!````!(`#0!G`P``M2H``,@!```2``T`
M^@,``$"``0``````$``7`&\$```5'0``I`$``!(`#0`O!```0(`!```````0
M`!<`6@,``+D>```6````$@`-`'T#``!M(P``>````!(`#0#>`P```#L```0`
M```1``\`"`0``%DY``#4````$@`-`!,$```Q'```.````!(`#0`;!```5)`!
M```````0`!<`1`0``%20`0``````$``7`%T$``#U(P``X````!(`#0#M`P``
M`(`!```````0`!8`H0,``-$>``"P````$@`-`%8$``!`@`$``````!``%@!\
M!```/(`!``0````1`!8`\P,``)46````````$@`-`#L$``#A.```>````!(`
M#0#O`P```(`!```````@`!8`MP,``.4C```0````$@`-`(L#``!I'```J```
M`!(`#0"M`P``+3H``+P````2``T`(P0``%20`0``````$``7`(8$``"!'P``
M[`,``!(`#0``7U]G;6]N7W-T87)T7U\`7TE435]D97)E9VES=&5R5$U#;&]N
M951A8FQE`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4&5R;%]S>7-?=&5R
M;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R
M=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?<W9?
M<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K
M97D`4&5R;%]C<F]A:U]M96UO<GE?=W)A<`!P97)L7V9R964`4&5R;%]M9U]S
M970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F
M971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!B;V]T
M7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R
M;%]A;&QO8P!?7V-X85]F:6YA;&EZ90!R96%D`'-T<F-H<@!G971P:60`;65M
M;6]V90!P=&AR96%D7V=E='-P96-I9FEC`%]?;&EB8U]S=&%R=%]M86EN`%]?
M9G!R:6YT9E]C:&L`<W1R8VUP`&]P96XV-`!U;FQI;FL`7U]S=')N8W!Y7V-H
M:P!S=')T;VL`;65M<V5T`'-T<FYC;7``9V5T=6ED`&UE;6-H<@!C;&]S961I
M<@!S=')S='(`<FUD:7(`8VQO<V4`<W1R;&5N`'-T<F1U<`!R96%L;&]C`')E
M861D:7(V-`!A8F]R=`!?7W-P<FEN=&9?8VAK`'-T9&5R<@!M96UC<'D`;'-T
M870V-`!O<&5N9&ER`&QS965K-C0`7U]E<G)N;U]L;V-A=&EO;@!E>&ET`')E
M861L:6YK`%]?<W1A8VM?8VAK7V9A:6P`86-C97-S`&UK9&ER`%]?96YV:7)O
M;@!?7W)E9VES=&5R7V%T9F]R:P!?7W-T86-K7V-H:U]G=6%R9`!L:6)P97)L
M+G-O+C4N,S0`;&EB8RYS;RXV`&QD+6QI;G5X+6%R;6AF+G-O+C,`<&%R7V-U
M<G)E;G1?97AE8P!P87)?8F%S96YA;64`6%-?26YT97)N86QS7U!!4E]"3T]4
M`'!A<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]D:7)N
M86UE`'-H85]F:6YA;`!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?
M8VQE86YU<`!?24]?<W1D:6Y?=7-E9`!?7V1A=&%?<W1A<G0`7U]B<W-?<W1A
M<G1?7P!S:&%?=7!D871E`'AS7VEN:70`7U]E;F1?7P!?7V)S<U]E;F1?7P!?
M7V)S<U]S=&%R=`!S:&%?:6YI=`!?96YD`'!A<E]M:W1M<&1I<@!?961A=&$`
M<&%R7W-E='5P7VQI8G!A=&@`<&%R7V9I;F1P<F]G`&UY7W!A<E]P;`!P87)?
M:6YI=%]E;G8`1TQ)0D-?,BXT`$=,24)#7S(N,S0`1TQ)0D-?,BXS,P``````
M`````@`!``(``@`!``$``0`!``$``@`!``$``@`!``(``0`!``(``@`"``(`
M`0`#``$``0`!``$``0`"``(``@`"``$``@`"``0``@`"``$``@`!``(``0`"
M``(``@`"``(``@`#``4``@`"``(``0`"``$``@`"``(``0`"``(``@`!``(`
M`0`%``(``@`"``(``@`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$````!``$`-0,``!`````@````
M%&EI#0``!`"3!`````````$``P`K`P``$`````````"TD98&```%`)T$```0
M````LY&6!@```P"H!```$````!1I:0T```(`DP0```````#L>P$`%P```/![
M`0`7````+'X!`!<````$@`$`%P````R``0`7````$(`!`!<````8@`$`%P``
M`!R``0`7````((`!`!<````D@`$`%P```"B``0`7````,(`!`!<````T@`$`
M%P```#R``0`7````_'T!`!4(````?@$`%0H```1^`0`5"P``"'X!`!42```,
M?@$`%1@``!!^`0`5&P``%'X!`!4<```8?@$`%20``!Q^`0`5)@``('X!`!4^
M```D?@$`%3\``"A^`0`52P``"'T!`!8#```,?0$`%@0``!!]`0`6!0``%'T!
M`!8&```8?0$`%@<``!Q]`0`6"0``('T!`!8+```D?0$`%@P``"A]`0`6#0``
M+'T!`!8.```P?0$`%@\``#1]`0`6$```.'T!`!81```\?0$`%A,``$!]`0`6
M%```1'T!`!85``!(?0$`%A8``$Q]`0`6%P``4'T!`!89``!4?0$`%AH``%A]
M`0`6'0``7'T!`!8>``!@?0$`%A\``&1]`0`6(```:'T!`!8A``!L?0$`%B(`
M`'!]`0`6(P``='T!`!8E``!X?0$`%B<``'Q]`0`6*```@'T!`!8I``"$?0$`
M%BH``(A]`0`6*P``C'T!`!8L``"0?0$`%BT``)1]`0`6+@``F'T!`!8O``"<
M?0$`%C```*!]`0`6,0``I'T!`!8R``"H?0$`%C,``*Q]`0`6-```L'T!`!8U
M``"T?0$`%C8``+A]`0`6-P``O'T!`!8Y``#`?0$`%CH``,1]`0`6.P``R'T!
M`!8\``#,?0$`%D```-!]`0`600``U'T!`!9"``#8?0$`%D,``-Q]`0`61```
MX'T!`!9%``#D?0$`%D8``.A]`0`61P``['T!`!9(``#P?0$`%DD``/1]`0`6
M2@``^'T!`!9+```(0"WI/`$`ZPB`O>@$X"WE!."?Y0[@C^`(\+[E%&L!``#&
MC^(6RHSB%/N\Y0#&C^(6RHSB#/N\Y0#&C^(6RHSB!/N\Y0#&C^(6RHSB_/J\
MY0#&C^(6RHSB]/J\Y0#&C^(6RHSB[/J\Y0#&C^(6RHSBY/J\Y0#&C^(6RHSB
MW/J\Y0#&C^(6RHSBU/J\Y0#&C^(6RHSBS/J\Y0#&C^(6RHSBQ/J\Y0#&C^(6
MRHSBO/J\Y0#&C^(6RHSBM/J\Y0#&C^(6RHSBK/J\Y0#&C^(6RHSBI/J\Y7A'
M_><`QH_B%LJ,XICZO.4`QH_B%LJ,XI#ZO.4`QH_B%LJ,XHCZO.4`QH_B%LJ,
MXH#ZO.4`QH_B%LJ,XGCZO.4`QH_B%LJ,XG#ZO.4`QH_B%LJ,XFCZO.4`QH_B
M%LJ,XF#ZO.4`QH_B%LJ,XECZO.4`QH_B%LJ,XE#ZO.4`QH_B%LJ,XDCZO.4`
MQH_B%LJ,XD#ZO.4`QH_B%LJ,XCCZO.4`QH_B%LJ,XC#ZO.4`QH_B%LJ,XBCZ
MO.4`QH_B%LJ,XB#ZO.4`QH_B%LJ,XACZO.4`QH_B%LJ,XA#ZO.5X1_WG`,:/
MXA;*C.($^KSE`,:/XA;*C.+\^;SE`,:/XA;*C.+T^;SE`,:/XA;*C.+L^;SE
M`,:/XA;*C.+D^;SE`,:/XA;*C.+<^;SE`,:/XA;*C.+4^;SE`,:/XA;*C.+,
M^;SE`,:/XA;*C.+$^;SE`,:/XA;*C.*\^;SE`,:/XA;*C.*T^;SE>$?]YP#&
MC^(6RHSBJ/F\Y0#&C^(6RHSBH/F\Y0#&C^(6RHSBF/F\Y0#&C^(6RHSBD/F\
MY0#&C^(6RHSBB/F\Y0#&C^(6RHSB@/F\Y0#&C^(6RHSB>/F\Y0#&C^(6RHSB
M</F\Y7A'_><`QH_B%LJ,XF3YO.4`QH_B%LJ,XESYO.4`QH_B%LJ,XE3YO.4`
MQH_B%LJ,XDSYO.4`QH_B%LJ,XD3YO.4`QH_B%LJ,XCSYO.4`QH_B%LJ,XC3Y
MO.4`QH_B%LJ,XBSYO.4`QH_B%LJ,XB3YO.5PM5M-B+!;2WU$6TS-Z000!:@#
MD@2I`ZI\1.M8&V@'DT_P``/_]\+O5$I52Z)8X%@11@+P[?I32^-8'7@`+6O0
M44OD6"!H__=F[P-&(&B3^,8C0O`"`H/XQB/_]USO!9V0^,8S*AT#-4/P`0.R
M\8!/@/C&,W/2D`#_]VSO0TH$G`-&>D1"27E$4&`B:!I@04H%F'I$VF!`2@$H
M"6AZ1)E@6F!>W2$=!.N`#@/Q#`Q1^`1+3/@$3W%%^=$#,#=.`"$`D2I&?D1#
M^"`0-4GP:'E$__<^[@1&>+,R30:N?43H:/_WSNXP2#%&>$0`\.7X0+,N2WM$
MV&C_]Q3N__>`[BQ*'$MZ1--8&F@'FUI`3_```RG1($8(L'"]__=*[B5*>D30
M8!"S__=V[A=+Y%@@:/_W\NZ`^'M7A>?P:/_W'.X$1LKGJ&@0L0'P+?O1YQI(
M,49X1`#PL?BH8``HR=#SY__WG.X$(*KG__>X[@$@__<V[QAH`0`@`0``"&@!
M``0!```8`0``*`$````!``#F:@$`VFH!`"XI```@*0``I&H!`!\&``",:@$`
ME"8``'9J`0`>9P$`2FH!`,@E``!/\``+3_``#@*\:D8$M`&TW_@8H`6CFD1/
M\``#"+0$2%KX``#_]^KN__>B[3QF`0`P`0``%#"?Y10@G^4#,(_@`B"3YP``
M4N,>_R\!T_[_ZB1F`0`(`0``!D@'2P=*>$1[1'I$@T(#T`5+TU@#L1A'<$<`
MOTII`0!(:0$``F8!``P!```(2`E+>$0)2GM$&QIZ1-D/`>NC`4D0`]`%2]-8
M`[$81W!'`+\@:0$`'&D!`-1E`0`0`0``"+4*2PI*>T1Z1!MX:[D)2]-8([$(
M2WM$&&C_][+N__>__P9+`2)[1!IP"+WJ:`$`I&4!`"P!``">:`$`RF@!`,3G
M`+\MZ?A#@48?2WM$`"@VT!Y*FUC3^`"`N/$`#S'0!7@/1@`M&+\]+12_`24`
M)1/1V/@`0&RQ1D8@1BI&24;_]T;N$+EC73TK$-!6^`1/`"SRT2!&O>CX@P5&
M%?@!/P`K&+\]*_G1I>L)!>'GINL(!@$U+$2V$#Y@($:]Z/B#!$;GYT1&Y>=@
M90$`'`$``#A*.4MZ1"WI\$&>L--8&V@=DT_P``,0L0-X!$9CN3-*,4MZ1--8
M&F@=FUI`3_```U71'K"]Z/"!__?<[`5&`"CMT"M/?T0H1O_W[NT`*#70PWP`
M\1,&+BL"T7-X`"ORT,-\+BLQT"!&__<X[8!&,$;_]S3M0$0",/_WANT[1D_P
M_S(!(0&6!D8`E/_WU.T"J3!&__<,[0$P,$8%T`:;`_1P0[/U@$\7T/_W'NTP
M1O_W[.PH1O_WN.T`*,G1*$;_]T3M($;_]WCMJ>=S>"XKRM&S>``KM]#&Y__W
MDO_FY__W6NT`O]AD`0`@`0``NF0!`#`C```72AA+>D00M01&G+#36&E&&V@;
MDT_P``/_]UKMH+D$FP/T<$.S]2!/&+^S]8!/#=`-2@Q+>D336!IH&YM:0$_P
M``,+T1RP$+T`(/'G`B$@1O_WK.RP^H#P0`GIY__W(.WD8P$`(`$``+1C`0`M
MZ?!##D8L22Q+K?6`77E$@[`$1@WU@%`$,-_XI(#+6`&O0/;_<CE&&V@#8$_P
M``,D2/A$>$3_]T+ML/$`#!O=`JT,\?\Y3405^`0\@[NY\0`/$=!*1B\A.$;_
M]V+M6+$92UCX`S`8:/_W`NU+1CI&(4;_]YSL">`32UCX`S`8:/_W]NPR1B%&
M__<T[`]*#?6`40I+!#%Z1--8&F@+:%I`3_```P;1#?6`70.PO>CP@^%&S^?_
M][[L;F,!`"`!``!*8P$`Z"$````!``#F8@$`6$I92WI$+>GP1PQ&@K`%1M-8
MW_A8@1MH`9-/\``#"WCX1#TK"+\!-"!&__=`[&E&!D8H1O_WAOZ!1@`H5-#_
M]S;LAD)'V4I+`)]8^`.`OP`K>``K&+\]*Q2_`2,`(P?0*T83^`$O`"H8OSTJ
M^=%;&[`<V/@`8!A$__=N[/!1Z+'8^``P*$;961#X`3L+<``K&+\]*PG02AP0
M^`$[$48"^`$[/2L8OP`K]M$*1CTC"W`4^`$[`O@!/P`K^=$M2BI+>D336!IH
M`9M:0$_P``-&T0*PO>CPAPGQ_SD4^`$["?@!/P`K^='IYR%+6/@#@-CX`'`[
M:(.S.T93^`0O248)\0$)`"KXT0,QB0`;2GI$$VB[N0A&`2,38/_W'NR"1@`H
MS-`Y1D_JB0<Z1O_W0.S(^`"@S?@`D`GQ`0D`(TKX*3"&YSA&__=R[()&R/@`
M```HM-!/ZHD'[.>91@@AU>?_]P+L`+^H8@$`(`$``(QB`0`<`0``[&$!`.AD
M`0`PM1%,$4N#L'Q$Y5@H:/_W"NPH:/_W!NP-2@Y+#DE[1*)8>43_]S[L*&C_
M]_SK"TL+2@`D"TE[1'I$S>D`-'E$__=JZP.P,+TH80$```$``!0!```V7P``
MOA\``)(B``"Q#@``OA\``!"U"$P(2WQ$XU@8:/_WUNL&2@=+!TE[1*)8>42]
MZ!!`__<*O,)@`0```0``%`$``-9>``!>'P``)$HPM21+>D2M]0!=B;`-]0!1
M!:S36!PQ&V@+8$_P``/_]\KK'4E!\@$"'4MY1,WI``%[1`$A($;_]];K#?6`
M41@Q($9/](!2`Y'_]\+K!!ZXOP`E"MM@'/_W<.L%1BBQ`YDB1O_W(.L`(RM5
M#4H-]0!1"4L<,7I$TU@::`MH6D!/\``#!-$H1@WU`%T)L#"]__=:ZXI@`0`@
M`0``5!\``$(?```:8`$`__>JOUM*+>GP3P9&6DMZ1*WUA%V#L%E(#?6$5`WQ
M&`C36`U&>$1!1@0T&V@C8$_P``/_]R7]+R$$1C!&__=XZL"Q3T@Q1GA$__=X
M_C!&34H-]8112$L$,7I$TU@::`MH6D!/\``#0/"#@`WUA%T#L+WH\(\P1O_W
MN.J!1BA&__?XZD%)>43_]QCK`"C9T#]+!T;?^/R@>T0%DSY+^D1[1`23.W@`
M*S[0++$Y1B!&__=TZP`H0=`X1O_WENI"'KL8NEPO*@;1`"4=<`$X$_@!+2\J
M^=`)\0$#`T2S]8!?L-HM2B&M`2%31GI$*$;-Z0$F3_2`4@"7__<DZT%&*$;_
M]USJ*+D*FP/T<$.S]0!/'=`B20`@>43_]]#J!T8`+Y#0.W@`*\#1!+,C>"XK
M`M`%GP$@S^=C>``K^=$920`@>43_][KJ!T8`+^K1>N<!(2A&__<LZ@`HV]$2
M2"E&>$3_]^W]*$;_]X3J<><$GP$@L>?_]Y;JVE\!`"`!``"\'@``IAX``)!?
M`0!X'@``1AX``&0>```^'@``(!X``.@=``"^'0``D!T```-X.[%"'"\K"+\0
M1A+X`3L`*_C1<$<`OQ"UJ+,#>`1&D[/_]P[J0QXC1)Q",M(:1@+@$T:B0BW0
M$T82^`$9+RGWT)Q")M(!.YQ")=`:>"\J^=$!.P/@$7@!.R\I`M$:1IQ"^-,2
M&Y,<L_6`7XB_`"`)V!%((49/](!3`3)X1`1&__>@Z2!&$+T,2+WH$$!X1/_W
M&+J<0MS1(W@O*P70"$B]Z!!`>$3_]PVZ!DB]Z!!`>$3_]P>Z`+\<80$`IAP`
M`+P<``"$'```W4K?^'C#WDMZ1'"U_$0,\0P,C+#;3M-8#?$(#GY$`:P;:`N3
M3_```]=-O.@/`*[H#P!]1+SH#P"NZ`\`W/@`,*[X`#`A1C!&__?B^["QSTL!
MF.M8&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZT2%&,$;_]\S[`"CHT<1.
M?D0A1C!&__?$^["QP$L!F.M8&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZ
MT2%&,$;_]Z[[`"CHT;9.?D0A1C!&__>F^["QL4L!F.M8&6@!ZX`#6FA!^"`@
M`"KOT`0S6FA#^`0K`"KZT2%&,$;_]Y#[`"CHT:A.?D0A1C!&__>(^["QHDL!
MF.M8&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZT2%&,$;_]W+[`"CHT9I.
M?D0A1C!&__=J^["QDTL!F.M8&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZ
MT2%&,$;_]U3[`"CHT8Q.?D0A1C!&__=,^["QA$L!F.M8&6@!ZX`#6FA!^"`@
M`"KOT`0S6FA#^`0K`"KZT2%&,$;_]S;[`"CHT7Y.?D0A1C!&__<N^["Q=4L!
MF.M8&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZT2%&,$;_]QC[`"CHT7!.
M?D0A1C!&__<0^["Q9DL!F.M8&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZ
MT2%&,$;_]_KZ`"CHT6).?D0A1C!&__?R^K"Q5TL!F.M8&6@!ZX`#6FA!^"`@
M`"KOT`0S6FA#^`0K`"KZT2%&,$;_]]SZ`"CHT51.?D0A1C!&__?4^K"Q2$L!
MF.M8&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZT2%&,$;_][[Z`"CHT49.
M?D0A1C!&__>V^K"Q.4L!F.M8&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZ
MT2%&,$;_]Z#Z`"CHT3A((49X1/_WF?H!1ABQ-DAX1/_W\?LU2"%&>$3_]X[Z
M`488L3)(>$3_]^;[,4@A1GA$__>#^@%&J+$O2'A$__?;^RY)+DAY1'A$__?5
M^RU*%DMZ1--8&F@+FUI`3_```QW1#+!PO2A((49X1/_W9OH!1B"Q)4AX1/_W
MOOOAYR1)"B(-\1D`>43_][[H`"C8T2!(#?$C`7A$__>N^]'G__=>Z`"_<%T!
M`)!;```@`0``@!P``$9=`0`<`0``*AP``/8;``#&&P``DAL``&8;``#&&@``
M^AH``,H:``":&@``XAD``"P:```(&@``*AH``#(:```T&@``8!D``$X:``"H
M&0``4EH!``H:``"6&0```AH``'89```72QA)&$I[1'E$`+48:(.PBEA#'!)H
M`9)/\``"#-`32A%+>D336!IH`9M:0$_P``,3T0.P7?@$^PU(:49X1/_W\?DP
ML0!X,"@8OP`H%+\!(``@"$M[1!A@X>?^]_3O`+^27`$`A%D!`"`!``!J60$`
MN!@``$1<`0`(M?[W5N_^]YCO`+$`:`B]+DHO2WI$\+4N3H>P!4;36'Y$!*DP
M1AMH!9-/\``#__>]^1"Q`W@$1HNY)THD2WI$TU@::`6;6D!/\``#/-$C2"E&
M>$0'L+WH\$#_]P6[*4;^]WSO6+$>2AE+>D336!IH!9M:0$_P``,FT0>P\+TH
M1O[W2.\'1B!&_O=$[SA$`C#^]Y;O$TL42@$A>T0"E'I$`)4!DD_P_S($1O[W
MX.\/2@=+>D336!IH!9M:0$_P``,$OR%&,$;%T/[W@.\`60$`(`$``.@8``#6
M6`$`MA@``*I8`0"2%P``BA<``&)8`0`MZ?!/W_A$%:WU`4W?^$!%@;#?^$"E
M?$1`KR(=I_%T`P>0#?4`1=_X,`4$\1`,_#4H-'A$I_%H#J?QX`;Z1$%8"6@I
M8$_P``&G\5P%!\J#Z`<`O.@/``_%G.@#`(7H`P"4Z`<`CN@'`-_X\`0Q1GA$
M__<D^2"Q`W@$1@`K0/!<@?[WGN[^]^#N`"@`\&V!!6@`+0#PDX$H1O[WQ.Y`
M``$P_O<6[RIX@$:"L=_XM+1$1OM$($8`DEM&3_#_,@$A`C3^]USO%?@!+P`J
M\M'?^)0$I_%8!7A$`N!5^`0+B+$Q1O_W[/@$1@`H]M`#>``K\]#_]Z3Y`"CO
MT"!&_O?8[@1&T+E/\``)I_%T"P?KB0)2^'1,A+$)\0$%"^N%!2)X4K$@1@GQ
M`0G_]XGY`"A;T57X!$L`+/+1`"0@1O[W=.Z#1D!&_O=P[H-$"_($2UA&_O?`
M[M_X%#1/\/\R`2%[1`*3W_@(-,WX#("`1GM$`9/?^``T`)1[1/[W`N]/].!Q
M0$;^]\KM`3`%T?[W,.\!:!$I0/#"@#%&0$;^][CN!49(L_1)!YOT2EKX`0!/
M\``*&VAZ1,WX`(`!(0!H_O>6[N]*#?4`0>%+_#%Z1--8&F@+:%I`3_```T#P
MMX%01@WU`4T!L+WH\(\@1O[W8.X$1@`HB]"AYU?XT#P#]'!#L_6`3\[15_C(
M3/[WW.V$0LC15_C0/,/S"`.S]>!_P=%81O[W6.Z"1M9(,49X1/_W1_@!1@`H
M`/#%@`>;&&C_]P'[@T8`*`#PO8!81O[W[.T$1@,H#]G,200X6$1Y1/[WO.Y`
MN00L`/`N@5Q$%/@%/"\K`/`H@<5,?$0C:%H<`/"E@``K`/"W@,%)PDAY1-_X
M")-X1,%/__=Q^<%._O=8[L!+3_#_,@$A>T0#D[Y+^43-^`"`?T1[1,WI`3"[
M2U!&?D1[1/[W7.X4X/[WDNX#:!$K%]'^]SSN`36$1DM&(D8!(5!&S>D#5\WI
M`6S-^`"`_O=&[D_TX'%01O[W$.T$1D,<XM!`1O[W9NVI2%%&>$3_]S3Y4$;_
M]P7^4N>62@>;6O@"`$_P``H;:*)*S>D`@0$A>D0`:/[WVNU"Y__W\OV=2H-+
M#?4`07I$_#'36!IH"VA:0$_P``-`\/B`($8-]0%-`;"]Z/!/_O>@O8!&I_%H
M!`?KB`-3^&@,R+$(\0$+!.N+!03@5?@$"XBQ"_$!"S%&V$;^]Y3_`"CTT`-X
M`"OQT/[WANT%1@`H?_1VKN#G@DT-(/[WCNU3(H!&?41VYJA&U.<'F]/X`+`^
MYWQ(,49X1/[W=?\`*`#PBH`#>``K&+\P*Q6_`2,`(P$C(V`8OR-@?_1)KUA&
M`"'^]S3M!$8`*#_T0:]/\/\S;_`1`@(F/1\`EO[W6.T&(BE&($;^]^#L%_@$
M/!NY%_@#/$,K8=``(P`B`),@1@`C_O=&[0#PY_\&1@/@*48P1@'P'?A/]`!"
M*48@1O[WQ.P"'O/<W_ADL2!&I_$P"?[W".VG\44%,4;[1$Q&I_$Q!J?Q1``!
M\&WX%?@!+R!&`));1D_P_S(!(?[W=NT"-*Y"\M%*2@$AS?@(D%!&>D1(2\WI
M`((`(@?X""Q[1$9*>D0#DD_P_S+^]U[M'N<'FUQH`"P_]-.N($;^]ZKL`RA_
M]LVN/4D$."!$>43^]WCM`"@(OZ-&PN8@8(#G%_@"/$$KF=$7^`$\0RN5T3MX
M2"N2T7MX12N/T4_P_S-O\#D"($8`EO[WU.PI1BDB($;^]USL*TLK24_P_S)[
M1,WI`E,I2WE$4$;-Z0"!>T0!(?[W'.W;YO[WR.P@`0``&EL!`.A7`0#R5P$`
MKA8``(`7```$%P``Z!8``-H5``#$%@``)`$``-@6``!<5@$`M!8``(P6``"\
M6`$`C!4``/X4``!J%@``#!<``(@4```8%P``DA0``$86```2%```'A4``.!4
M`0!P%```P!,``,(3``"B$@``1!0```@5```.%```CA0```X2``"V$P``7TA@
M27A$\+5?2X.P7TI!6'M$;D8):`&13_```9Q8(&C^]XKL!48@:/[WANPQ1I7X
M:#"`^&DP5DAX1/[W3_X0L0-X,2MZT/_W0?H@:/[W=.Q020,C`2)Y1/[WI.L%
M1FBQ(&C^]VKL*VE+2AEH>D3^]Z;K*VD;:)MH6P)NU"!H_O=<[$9)`R,!(GE$
M_O>,ZP5&>+%#2#%&>$3^]R#^!T8@:``O3]#^]TCL*VDZ1AEH_O>&ZR!H_O=`
M[`5&(&C^]SSL.$D!(GE$_O=0ZS=*`48H1GI$-DW^]W+K(&C^]R[L`T9]1#-(
M`"(Q1GA$@_AI(/[W]?T$1JA@L+%/].!Q($;^]QSK0AP#1A$H&+\!*B_8*4H<
M2WI$TU@::`&;6D!/\``#(]$#L/"]:&C_]WK\!$:H8``HX=$@2'A$_O<2[$-X
M`"N#T(#G_O?XZQQ+*FE[1!!H6V@9:/[WN/ZKYR!H_O?LZRMI&6C^][CKB.?^
M]\CK%$DB1A1(>41X1$EH"6C^]_#K0%(!`"`!```T4@$```$``%@1``#R$@``
MX!(``,P2``"R$```E!(``*`2``"L5`$`5!```#)1`0!"$@``0%0!`!A4`0`F
M$@``,DHS2WI$\+4'1H.PTU@;:`&33_```__W'?D#>`1&.[%"'"\K"+\41A+X
M`3L`*_C1*$X]'AB_`25^1#-H6APLT``K#+\`)07P`05=N2)*($MZ1--8&F@!
MFUI`3_```S+1`[#PO3MX`"OPT!Q)!"(@1GE$_O>VZP`HZ-$92A1+>D336!IH
M`9M:0$_P``,;T3A&`["]Z/!`_O>#O1)(:49X1/[W./UHL0-X`"L8OS`K"K\`
M(P$C,V#)T`$C,V``+<70T.<P8,+G_O<VZP"_>%`!`"`!``!04P$`+%`!`"P0
M``#^3P$`1@\````````MZ?!/`/%``=_X8$O?^&`[K?4C?7Q$[D9R1@#Q@`P`
M)^-8&VBADT_P``-1Z0)D5V#78!`R-KI"^!!L(PHE`@/T?T,(,4/J%&,%]'\%
M0^H$8V%%0^H%`T+X"#SFT:WQ"`8.]?QW`".$1C1&5O@(#]3I!H4B;]3X2*!A
M;]3X3)""Z@H"=&B"Z@@"@>H)`4)`:4#&^(0P84"4&-(/OD)"ZD$"0NH$`L;X
M@"#>T6!&WO@`4-SI`R:$:-SI`'E/ZI0(`IE(ZH)X1_:9$L7V@B)(ZH1X!&JM
M&$_JUVS=^!#@3.I)'"T9A&E,ZD<<'.L%!=WX<*"&Z@0,A&@,Z@0,A&F,Z@0,
M%>L,!8;J"`R)&`SJ!PP)&8SJ!@P1ZPP,'NL"`4_JEPZ)&4[JB7[=^!B03NJ'
M=`SK]6R(Z@0.#NH%#D_JM06.Z@@.$>L.#AGK`@$1ZP@!A.H%"-WX()`(Z@P(
MB.H$"`[K_&X1ZP@(3^J\#!GK`@'=^"B0"1F%Z@P$!.H.!`CK_FAL0$_JO@X,
M&1GK`@%)&8SJ#@7=^#"0!>H(!87J#`4$Z_AD31E/ZK@(&>L"`=WX.)`1ZPP!
MCNH(#`SJ!`P%Z_1EC.H.#$_JM`01ZPP,&>L"`1'K#@&(Z@0.W?A`D`[J!0Z.
MZ@@.#.OU;!'K#@Y/ZK4%&>L"`=WX2)`1ZP@!A.H%"`CJ#`@.Z_QNB.H$"$_J
MO`P1ZP@(&>L"`0D9A>H,!-WX4)`$Z@X$;$`(Z_YH#!E/ZKX.&>L"`=WX6)!)
M&8SJ#@4%Z@@%!.OX9(7J#`5/ZK@(31D9ZP(!$>L,`8[J"`S=^&"0#.H$#(SJ
M#@P%Z_1E$>L,#$_JM`09ZP(!W?AHD!'K#@&(Z@0.#NH%#@SK]6R.Z@@.3^JU
M!1'K#@X9ZP(!$>L(`83J!0@(Z@P(#NO\;HCJ!`A/ZKP,$>L("!KK`@$)&87J
M#`0(Z_YI!.H.!-WX>(!L0$_JO@X)&1CK`@3=^("`9!F,Z@X%!>H)!0'K^6&%
MZ@P%3^JY"609&.L"!17K#`6.Z@D,W?B(@`SJ`0R,Z@X,!.OQ9!7K#`Q/ZK$!
M&.L"!=WXD*`5ZPX%B>H!#@[J!`X,Z_1LCNH)#D_JM`05ZPX%&NL"#A[K"0Z!
MZ@0)!>O\:`GJ#`DFG8GJ`0E/ZKP,'NL)#JH8W?B@H%(8A.H,`0'J"`$.Z_AN
M84!/ZK@%41A.]J$RQO;98MWXJ(`:ZP(*`>O^81KK!`2,Z@4*BNH."D_JO@X4
MZPH$W?BPD!CK`@B%Z@X*!.OQ9(KJ`0H8ZPP,3^JQ`=WXN(`<ZPH,&>L""8[J
M`0H,Z_1LBNH$"AGK!05/ZK0$%>L*!=WXP)`8ZP((@>H$"@7K_&6*Z@P*&.L.
M#D_JO`P>ZPH.W?C(@(3J#`H9ZP()BNH%"AGK`0D.Z_5A&>L*"4_JM048ZP(*
MW?C0X!KK!`H)Z_%DC.H%"8GJ`0E/ZK$!&NL)"A[K`@G=^-B`&>L,"0KK]&R%
MZ@$*BNH$"D_JM`09ZPH)&.L""MWXX.`:ZP4*">O\98'J!`F)Z@P)3^J\#!KK
M"0H>ZP()W?CH@!GK`0D*Z_5AA.H,"HKJ!0I/ZK4%&>L*"1CK`@C=^/#@&.L$
M"`GK\62,Z@4)B>H!"4_JL0$8ZPD('NL"#MWX^*`>ZPP.A>H!#`CK]&B,Z@0,
M3^JT!-WX`)$>ZPP.&NL"#('J!`H.Z_ANBNH("ASK!0Q/ZK@('.L*#$*=A.H(
M"AGK`@D,Z_YLBNH."AGK`0E/ZKX.&>L*"429K1B(Z@X*BNH,"BP9">O\94_J
MO`P4ZPH$W?@8D8[J#`J)&`3K]62*Z@4*$>L(`4_JM041ZPH!C.H%"AGK`@D!
MZ_1ABNH$"MWX(($9ZPX)3^JT"QGK"@G=^"CA">OQ9!CK`@B%Z@L)&.L,"(GJ
M`0E/ZK$!&.L)"=WX,,$>ZP(*B^H!#H[J!`X:ZP4*">OT94_JM`0:ZPX*@>H$
M"-WX..$<ZP(,B.H%"!SK"PP*Z_5J'.L(#$_JM04>ZP("4AB$Z@4!W?A`X8'J
M"@%/ZKH(41A+]MQ"R/8;<@SK^FP>ZP(.1>H("MWX2)$>ZP0$"NH,"@7J"`X!
MZ_QA2NH."D_JO`P4ZPH.&>L"!&092.H,!0CJ#`K=^%"1#4`.Z_%N1>H*!4_J
ML0$M&1GK`@E,Z@$$&>L("@SJ`0O=^%B1!.H.!`7K_F5$Z@L$3^J^#A3K"@09
MZP()&>L,"4'J#@P!Z@X*W?A@@0SJ!0P$Z_5D3.H*#$_JM04<ZPD,&.L""!CK
M`0$,Z_1H3NH%#`[J!0K=^&B1#.H$#$SJ"@Q/ZK0$'.L!#!GK`@E%Z@0!&>L.
M"@7J!`O=^'"1`>H(`0SK^&Q!Z@L!3^JX#A'K"@$9ZP()&>L%"@'K_&5$Z@X!
M3^J\"=WX>($!Z@P!!.H.#$'J#`$1ZPH,&.L"`0D93NH)!`[J"0K=^("!+$`,
MZ_5L1.H*!$_JM05D&$GJ!0H8ZP((!.O\9!CK#@ABF4_JO`X*Z@P*">H%#$KJ
M#`H:ZP@,B1@1ZPD(1>H."07J#@IDF0GJ!`D,Z_1L2>H*"4_JM`09ZP@(B1A)
M&4[J!`4.Z@0)!>H,!47J"04(Z_QH;1AFF4_JO`P%Z_AEB1A$Z@P)!.H,"A'K
M#@X)Z@@):)E)Z@H)3^JX"!GK#@F)&!'K!`X)Z_5D3.H("0SJ"`IJF0GJ!0E)
MZ@H)3^JU!1GK#@Z)&!'K#`%(Z@4,".H%"0SJ!`Q,Z@D,#NOT;ASK`0QLF4_J
MM`0,Z_YLB1A%Z@0)!>H$"A'K"`@)Z@X);IE)Z@H)3^J^#AGK"`F)&!'K!0@)
MZ_QE1.H."03J#@IPF0GJ#`E)Z@H)3^J\#!GK"`E.Z@P(B1@(Z@4("1D)Z_5D
M#NH,"4_JM05(Z@D(3.H%"1CK`0ARF0SJ!0H)Z@0)B1@(Z_1H$>L.#G293^JT
M!$GJ"@D9ZPX)B1A%Z@0.">OX:1'K#`H.Z@@.3^JX#':9!>H$"$-@3NH(#@3J
M#`@>ZPH.BAA2&43J#`4%Z@D%>)E%Z@@%#NOY;JT83/+6$LSV8B)/ZKD)$>L"
M"'J9&.L$"(SJ"02$Z@X$!>O^91CK!`A/ZKX.B1B)Z@X$$>L,#'R9;$`(Z_5H
M'.L$#$_JM06)&([J!001ZPD)?ID,Z_ALA.H(!!GK!`E/ZK@(C!B`F13K#@0)
MZ_QNA>H("<-@B>H,"4_JO`P4ZPD$$>L""1GK!0F"F8CJ#`4$Z_YDA>H.!4_J
MO@X9ZP4)C1@5ZP@%A)D)Z_1HC.H."8GJ!`E/ZK0$%>L)!1'K`@D9ZPP)AIF.
MZ@0,!>OX98SJ"`Q#81GK#`E/ZK@,$>L""(B9&.L."`GK]6Z$Z@P)PV&)Z@4)
M3^JU!1CK"0@1ZP()&>L$"8J9".O^9(SJ!0B(Z@X(3^J^#AGK"`D1ZP((&.L,
M"(R9">OT;(7J#@F)Z@0)3^JT!!CK"0@1ZP()&>L%"8Z9".O\98[J!`B(Z@P(
M3^J\#!GK"`D1ZP((&.L.")"9">OU;H3J#`F)Z@4)3^JU!1CK"0@1ZP()&>L$
M"9*9".O^9(SJ!0B(Z@X(3^J^#AGK"`D1ZP((&.L,")29">OT;(7J#@F)Z@0)
M3^JT!!CK"0@1ZP()&>L%"9:9".O\98[J!`B(Z@P(3^J\#!GK"`D1ZP((&.L.
M")B9">OU;H3J#`F)Z@4)3^JU!1CK"0B)&!'K!`D(Z_YDFIF,Z@4(B.H."$_J
MO@X9ZP@)B1@1ZPP(">OT;(7J#@F<F8GJ!`E/ZK0$&.L)"8D8">O\:4T9GID&
MZ[D&!F&.Z@0&ANH,!D_JO`RM&8H8TAF$Z@P!@>H)`1+K#@(%Z_EE4AB!:`+K
M]6)I&(5I`F`":ASK!06!8*08"TK`Z0A#"4MZ1(5ATU@::*&;6D!/\``#`]$-
M]2-]O>CPC_WW<.T`OWQ/`0`@`0``1$0!``BU@"#]]U[MG^T/>P`B@F>`[0![
MG^T.>X#M`GN?[0Y[@.T$>Y_M#GN`[09[G^T.>X#M"'N?[0Y[@.T*>X#M#'L(
MO0"_K_,`@`$C16<`````B:O-[P````#^W+J8`````'94,A``````\.'2PP``
M`````````````"WI^$,%1A9&@&H`(PQ&]Q?5Z0PA`.O&#(1%Z&ISZP```M(!
M,D'Q``&H;P7Q.`C%Z0K#<P]#ZL<#FQ@K8T'K5W%I8X"[/RY#W:;Q0`E/ZID6
M=QP$ZX<7(49#1@3Q0`[1^`#`$#%1^`Q,$#-1^`@,4?@$+'%%0_@0S$/X#$Q#
M^`@,0_@$+.O1#$8H1O_WP?F\0N'1J>N&%C)&.49`1OWWC.RN9[WH^(/`\4`'
M(4:W0D!$J+\W1CI&_?>`[*MO.T2K9T`K[M$H1O8;/$3_]Z'YN><G1N#G+>GP
M00'Q.`<,1HMJ!48.:X`AD_J#^,/SQ0,VNEH<N!@X*OE41-W"\4`"`"']]P3L
M($;_]X/Y.$8X(@`A_??\ZR!&Q.D<:/_W>?GC>"MP($9CB&MP(V@;"JMP(VCK
M<.-Z*W%CB6MQHV@;"JMQHVCK<>-\*W)CBFMR(VD;"JMR(VGK<N-^*W-CBVMS
MHVD;"JMSHVGK<Y3X(S`K=&.,:W0C:AL*JW0C:NMTO>CP0?WWXKO"\3@"`"']
M]\#KP><"2WM$&VC]]XF\`+\610$`"$`MZ0B`O>@!``(`.P```#X````+````
M/@```!`````^````)0```#X````S````/@````,````^````!@```#X````4
M````/@````X````^````#0```#X````D````/@```!(````^````)P```#X`
M```"````/@```!@````^````"0```#X````*````/@``````````````)7,O
M)7,````O<')O8R]S96QF+V5X90``1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A
M9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````"]P<F]C+R5I+R5S`&5X90`N
M````4$%27U1%35``````4$%27U!23T=.04U%`````#H````E<R5S)7,``"\`
M``!015),-4Q)0@````!015),3$E"`%!%4DPU3U!4`````%!%4DQ)3P``4$%2
M7TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@```%!!4E]$14)5
M1P```%!!4E]#04-(10```%!!4E]'3$]"04Q?1$5"54<`````4$%27T=,3T)!
M3%]435!$25(```!005)?5$U01$E2``!005)?1TQ/0D%,7U1%35``4$%27T=,
M3T)!3%]#3$5!3@````!005)?0TQ%04X]```Q````3$1?3$E"4D%265]0051(
M`%-94U1%30``)3`R>``````E<R5S)7,E<P````!P87(M`````"5S.B!C<F5A
M=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO
M/25I*0H``"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@
M*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H`
M`%!!5$@`````<&%R;``````N<&%R`````"5S)7-C86-H92TE<R5S```E<R5S
M=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E<P`````8````<&5R;``````P
M````4$%2.CI086-K97(Z.E9%4E-)3TX`````,2XP-30```!5;F%B;&4@=&\@
M8W)E871E(&-A8VAE(&1I<F5C=&]R>0`````E<SH@8W)E871I;VX@;V8@<')I
M=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*
M`````"UE```M+0``55-%4@````!54T523D%-10````!414U01$E2`%1-4``O
M=&UP`````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D
M0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C
M:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1P87)?=&5M<"P@)'!R
M;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%
M3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@
M1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I
M<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H
M<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN
M9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL
M("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M
M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ
M5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A
M<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I5
M3DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64[
M"G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@
M73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M
M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*
M9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P
M,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL
M(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG
M<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI
M.PI]"GT@?0I"14=)3B!["B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["DEN
M=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI0
M05(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]
M("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^
M("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]
M/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@
M)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<
M7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;7"1P<F]G
M;F%M92`]("(D<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ
M<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FUY("@D
M<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?
M5T%23E]??2`]('-U8B![?3L*=6YL97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@
M)'!R;V=N86UE*2!["F]U=',H<7%;0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P
M<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER
M97,@17)R;F\N<&T*;&%S="!-04=)0SL*?0IM>2`D8VAU;FM?<VEZ92`](#8T
M("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R!?1D@["FUY("1M86=I
M8U]P;W,@/2`D<VEZ92`M("1S:7IE("4@)&-H=6YK7W-I>F4[(",@3D]413H@
M)&UA9VEC7W!O<R!I<R!A(&UU;'1I<&QE(&]F("1C:'5N:U]S:7IE"G=H:6QE
M("@D;6%G:6-?<&]S(#X](#`I('L*<V5E:R!?1D@L("1M86=I8U]P;W,L(#`[
M"G)E860@7T9(+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%27TU!
M1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@
M/CT@,"D@>PHD;6%G:6-?<&]S("L]("1I.PIL87-T.PI]"B1M86=I8U]P;W,@
M+3T@)&-H=6YK7W-I>F4["GT*:68@*"1M86=I8U]P;W,@/"`P*2!["F]U=',H
M<7%;0V%N)W0@9FEN9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B(&EN(&9I
M;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0SL*?0IS965K(%]&2"P@)&UA
M9VEC7W!O<R`M(#0L(#`["G)E860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@
M)&UA9VEC7W!O<R`M(#0@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,#L*)&1A=&%?
M<&]S(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D
M8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@
M9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&
M2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I
M.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%
M("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S
M?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA
M;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*
M<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB
M+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z
M<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D
M8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M
M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@
M*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8F%S96YA;64D97AT(BP@
M)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L
M<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L
M"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*)')E<75I<F5?
M;&ES='LD9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C
M86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E
M='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2`D
M36]D=6QE0V%C:&5[)&UO9'5L97T["G)E='5R;B!U;FQE<W,@)&EN9F\["F1E
M;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U;&5](#T@
M(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@
M86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&
M:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T96UP(&9I
M;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB
M=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM
M>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN
M9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*;W!E;B!M
M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A
M9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T
M<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*
M?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V
M>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A
M=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)
M3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E
M<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@
M)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN
M<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I
M;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L
M)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"G5N
M;&5S<R`H)&)U9B!E<2`B4$M<,#`S7#`P-"(I('L*;W5T<RAQ<5M.;R!Z:7`@
M9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=
M*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T
M.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G
M<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID
M96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@
M;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@
M)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=
M(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD
M(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N
M:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF
M("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!
M4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS
M92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW
M:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4
M=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?
M=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D
M,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@
M)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@
M*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E
M<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I
M('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO
M9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B
M)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]
M("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[
M)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR
M97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE
M<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8[
M"F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@
M*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z
M.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H
M0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@
M)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A<B!F
M:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP
M(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N
M9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@
M9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM
M>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC
M;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M
M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI
M.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@
M)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F
M:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*
M9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@
M97$@(E!+7#`P,UPP,#0B.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T
M*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/
M7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/
M7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE
M("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`[
M"FUY("1L;V%D97(["FEF("AD969I;F5D("1D871A7W!O<RD@>PIR96%D(%]&
M2"P@)&QO861E<BP@)&1A=&%?<&]S.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N
M9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)
M37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M
M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T
M(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD
M=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC
M(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@
M(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA
M9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@
M+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*
M:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D
M=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH
M)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[
M87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB
M97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I;F,[
M"FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?
M<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#
M;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?97AT
M('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R
M="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E9FEN
M960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L*
M*"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C
M:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N
M*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]
M"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF("AM
M>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]
M("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I
M;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN
M97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N>R1N
M86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<
M421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@
M(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI
M.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D
M9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD968["F]P96X@
M;7D@)&9H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B
M)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1F:#X["F-L;W-E("1F:#L*4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D
M960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@
M/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT
M96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0HD
M9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y
M*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-2
M0S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT
M96YT*2DL"B1C;VYT96YT*3L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=
M*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*
M)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H
M(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI
M('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P96X@;7D@)&9H
M+"`B/#IR87<B+"`D;W5T.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E("1F
M:#L*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA
M;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H
M95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD
M9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E
M<BDI*3L*)&9H+3YP<FEN="@D4$%27TU!1TE#*3L*)&9H+3YC;&]S93L*8VAM
M;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@
M)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2
M.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ
M1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I
M;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV
M93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH
M9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@
M)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D
M>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE
M2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+
M*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!R
M;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#8T("H@,3`R
M-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE
M>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"54=]
M.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S
M970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^
M;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@
M)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S
M("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O
M;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]
M+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D
M9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0
M?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@
M/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI
M<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@
M870@(B1D97-T7VYA;64B72D["GT@96QS92!["F]U=',H<7%;17AT<F%C=&EN
M9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92)=*3L*)&UE;6)E<BT^
M97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PIC:&UO9"@P-34U+"`D
M9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H
M)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S
M<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@
M+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"
M?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%
M?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A
M=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N
M86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E
M;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL
M93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@
M)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER
M95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*
M<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N
M:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R
M<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE
M879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E
M($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO
M861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q
M=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER
M92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["G)E<75I<F4@
M4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR
M97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I
M;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@
M>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L
M('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C
M:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S
M:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q
M=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T[
M"GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]4
M14U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M
M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.
M5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0
M("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E
M9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S
M97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H
M)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G
M:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*
M96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*
M?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM5
M4T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<5R]?+V<["FUY
M("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(
M*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PII9B`H(21%
M3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE
M*2E;.5TI('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D
M:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PIS965K("1F:"P@
M+3$X+"`R.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@-CL*:68@*"1B=68@
M97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G)E860@)&9H+"`D
M8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B)'-Y<WM?
M9&5L:6U]8V%C:&4M)&)U9B(["GT*96QS92!["FUY("1D:6=E<W0@/2!E=F%L
M"GL*<F5Q=6ER92!$:6=E<W0Z.E-(03L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!
M+3YN97<H,2D["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@
M9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*)&-T>"T^861D
M9FEL92@D9F@I.PIC;&]S92@D9F@I.PHD8W1X+3YH97AD:6=E<W0["GT@?'P@
M)&UT:6UE.PHD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U]8V%C:&4M)&1I9V5S
M="(["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@
M,3L*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[
M4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL
M87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D
M14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]S879E7V%S('L*;7D@
M*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@
M/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*
M;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["F]P96X@;7D@)&9H+"`G
M/CIR87<G+"`D=&5M<&YA;64@;W(@9&EE('%Q6T-A;B=T('=R:71E("(D=&5M
M<&YA;64B.B`D(5T["G!R:6YT("1F:"`D8V]N=&5N=',["F-L;W-E("1F:#L*
M8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA
M;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I
M.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII
M9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!2
M3T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N
M86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O
M9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U
M8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM
M?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D
M<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D
M9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@
M*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y
M<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O
M7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X
M:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0
M?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE
M(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA
M<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE
M?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B
M*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]
M"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.
M5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D
M96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G
M;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#
M=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I
M;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M
M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D
M96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B
M(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK
M(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:
M141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@
M0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[)U!!4E\G+B1??3L*
M?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[
M)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S
M("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`](")?
M7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["FEF("@D14Y6>U!!
M4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF("@A
M97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@
M<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.
M5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<
M4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L
M;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B
M0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S
M:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]
M+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L
M:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E
M(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD
M7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@
M0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F
M:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D
M<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?
M7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`
M(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?
M5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%
M4E)/4CL*,3L*7U]%3D1?7PH```!P97)L>'-I+F,```!?7T5.5E]005)?0TQ%
M04Y?7R`@("`@("`@("`@("`@(``````[````/@````L````^````$````#X`
M```E````/@```#,````^`````P```#X````&````/@```!0````^````#@``
M`#X````-````/@```"0````^````$@```#X````G````/@````(````^````
M&````#X````)````/@````H````^``````````````"TFO]_`0````````"-
M%P``31<```$````;`P```0```"L#```!````-0,```P```#,$0``#0```/@Z
M```9````['L!`!L````$````&@```/![`0`<````!````/7^_V^T`0``!0``
M`"P)```&````G`(```H```"S!```"P```!`````5``````````,```#\?`$`
M`@```.@!```4````$0```!<```#D#P``$0```!0/```2````T````!,````(
M````'@````@```#[__]O`0``"/[__V^T#@``____;P(```#P__]OX`T``/K_
M_V\.````````````````````````````````````````````````````````
M`/1[`0```````````-@1``#8$0``V!$``-@1``#8$0``V!$``-@1``#8$0``
MV!$``-@1``#8$0``V!$``-@1``#8$0``V!$``-@1``#8$0``V!$``-@1``#8
M$0``V!$``-@1``#8$0``V!$``-@1``#8$0``V!$``-@1``#8$0``V!$``-@1
M``#8$0``V!$``-@1``#8$0``V!$``-@1``#8$0``V!$``-@1``#8$0``V!$`
M`-@1``#8$0``V!$``-@1``#8$0``V!$``-@1``#8$0``V!$``-@1``#8$0``
MV!$``-@1``#8$0``V!$``-@1``#8$0``V!$``-@1````````````````````
M``````````````````````````````````````````````#9%```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````!(`!`/_____`/@``\#L```````"P/```M#P``+0^``#X
M.P``O#X```````"@/@``J#X```````#(/@``1T-#.B`H56)U;G1U(#$Q+C(N
M,"TQ-G5B=6YT=3$I(#$Q+C(N,`!!,@```&%E86)I``$H````!3<M00`&"@=!
M"`$)`@H$$@03`10!%0$7`Q@!&0$:`AP!(@$`+G-H<W1R=&%B`"YI;G1E<G``
M+FYO=&4N9VYU+F)U:6QD+6ED`"YN;W1E+D%"22UT86<`+F=N=2YH87-H`"YD
M>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E
M;"YD>6X`+G)E;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N05)-
M+F5X:61X`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN
M86UI8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`+D%232YA='1R:6)U=&5S
M``````````````````````````````````````````````````````````L`
M```!`````@```%0!``!4`0``&0```````````````0`````````3````!P``
M``(```!P`0``<`$``"0```````````````0`````````)@````<````"````
ME`$``)0!```@```````````````$`````````#0```#V__]O`@```+0!``"T
M`0``Z`````4`````````!`````0````^````"P````(```"<`@``G`(``)`&
M```&`````P````0````0````1@````,````"````+`D``"P)``"S!```````
M```````!`````````$X```#___]O`@```.`-``#@#0``T@````4`````````
M`@````(```!;````_O__;P(```"T#@``M`X``&`````&`````@````0`````
M````:@````D````"````%`\``!0/``#0````!0`````````$````"````',`
M```)````0@```.0/``#D#P``Z`$```4````5````!`````@```!\`````0``
M``8```#,$0``S!$```P```````````````0`````````=P````$````&````
MV!$``-@1`````P`````````````$````!````((````!````!@```-@4``#8
M%```("8`````````````"`````````"(`````0````8```#X.@``^#H```@`
M``````````````0`````````C@````$````"`````#L````[``#@0```````
M```````$`````````)8````!``!P@@```.![``#@>P``"`````T`````````
M!`````````"A`````0````(```#H>P``Z'L```0```````````````0`````
M````JP````X````#````['L!`.Q[```$```````````````$````!````+<`
M```/`````P```/![`0#P>P``!```````````````!`````0```##````!@``
M``,```#T>P$`]'L```@!```&``````````0````(````S`````$````#````
M_'P!`/Q\```T`0`````````````$````!````-$````!`````P````"``0``
M@```0```````````````!`````````#7````"`````,```!`@`$`0(```!00
M``````````````0`````````W`````$````P`````````$"````F````````
M```````!`````0```.4````#``!P``````````!F@```,P``````````````
M`0`````````!`````P``````````````F8```/4```````````````$`````
#````
